summaryrefslogtreecommitdiffstats
path: root/sbin/tunefs/tunefs.c
diff options
context:
space:
mode:
authortrhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
committertrhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
commit136be46680c6e4a18cc827da991d4f9a0de29cba (patch)
treeb5ee0aba66633a4e0e47097e4f383c253a87887a /sbin/tunefs/tunefs.c
parent9618da3e35435c433d8086d65af15f716ffe32ec (diff)
downloadFreeBSD-src-136be46680c6e4a18cc827da991d4f9a0de29cba.zip
FreeBSD-src-136be46680c6e4a18cc827da991d4f9a0de29cba.tar.gz
s/filesystem/file system/g as discussed on -developers
Diffstat (limited to 'sbin/tunefs/tunefs.c')
-rw-r--r--sbin/tunefs/tunefs.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/sbin/tunefs/tunefs.c b/sbin/tunefs/tunefs.c
index e272446..15373ce 100644
--- a/sbin/tunefs/tunefs.c
+++ b/sbin/tunefs/tunefs.c
@@ -46,7 +46,7 @@ static const char rcsid[] =
#endif /* not lint */
/*
* tunefs: change layout parameters to an existing filesystem.
*/
#include <sys/param.h>
#include <sys/mount.h>
@@ -214,7 +214,7 @@ again:
err(1, "%s", special);
}
if (fs == NULL && (st.st_mode & S_IFMT) == S_IFDIR)
- errx(10, "%s: unknown filesystem", special);
+ errx(10, "%s: unknown file system", special);
getsb(&sblock, special);
if (pflag) {
@@ -327,7 +327,7 @@ again:
if (mount("ufs", fs->fs_file,
stfs.f_flags | MNT_UPDATE | MNT_RELOAD, &args) < 0)
err(9, "%s: reload", special);
- warnx("filesystem reloaded");
+ warnx("file system reloaded");
}
exit(0);
}
@@ -338,7 +338,7 @@ usage()
fprintf(stderr, "%s\n%s\n%s\n",
"usage: tunefs [-A] [-a maxcontig] [-d rotdelay] [-e maxbpg] [-f avgfilesize]",
" [-m minfree] [-p] [-n enable | disable] [-o space | time]",
-" [-s filesperdir] special | filesystem");
+" [-s filesperdir] special | file system");
exit(2);
}
@@ -369,7 +369,7 @@ getsb(fs, file)
break;
}
if (sblock_try[i] == -1)
- err(5, "Cannot find filesystem superblock");
+ err(5, "Cannot find file system superblock");
dev_bsize = fs->fs_fsize / fsbtodb(fs, 1);
sblockloc = sblock_try[i] / dev_bsize;
}
@@ -46,7 +46,7 @@ static const char rcsid[] =
#endif /* not lint */
/*
- * tunefs: change layout parameters to an existing filesystem.
+ * tunefs: change layout parameters to an existing file system.
*/
#include <sys/param.h>
OpenPOWER on IntegriCloud